/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of ADC demo for the
 *          TOSHIBA 'TMPM37A' Device Series
 * @version V0.100
 * @date    2015/11/02
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */


/* This demo is to show ADC function with software trigger on M37A-SK board      */
/* The loop blinking speed of the 4 LEDs is varied depend on the AD result.      */
#include "tmpm37A_adc.h"
#include "led.h"
struct mySoftTimer {
    uint32_t flag_TimeUp;
    uint32_t time_Cnt;
}softT;
#define DELAYCONST  20000U
static void softTimer(void); 

ADC_Result result = { 0U };
WorkState adcState = BUSY;
uint32_t myResult = 0U;
uint32_t idx = 0U;
uint32_t cnt = 0U;

   
int main()
{
    /* 1. set ADC clock */
    ADC_SetClk(TSB_AD, ADC_HOLD_FIX, ADC_FC_DIVIDE_LEVEL_8);

    /* 2. select trigger and AD channel, this time we use sofeware trigger, */
    /*    the VR1 is connected to  ADC unit B channel 9, remember to input with macro TRG_ENABLE() */
    ADC_SetSWTrg(TSB_AD, ADC_REG0, TRG_ENABLE(ADC_AIN9));
    
    /* 3. enable ADC module */
    ADC_Enable(TSB_AD);

    /* 4. now start ADC */
    ADC_Start(TSB_AD, ADC_TRG_SW);

    /* initialize LEDs on M37A-SK board before display something */
    LED_Init();
    
    softT.time_Cnt = DELAYCONST;
    while (1U) {
        /* check ADC module state */
        adcState = ADC_GetConvertState(TSB_AD, ADC_TRG_SW);

        if (adcState == DONE) {
            /* read ADC result when it is finished */
            result = ADC_GetConvertResult(TSB_AD, ADC_REG0);

            /* get the real ADC result without other information */
            /* "/256" is to limit the range of AD value */
            myResult = 16U - result.Bit.ADResult / 256U;
            /* software trigger, need to trigger it again */
            ADC_Start(TSB_AD, ADC_TRG_SW);
        } else {
            /* Do nothing */
        }   
       softTimer();  
       if(softT.flag_TimeUp) {
            softT.flag_TimeUp = 0U;
            cnt++;
            if( cnt >= myResult ) {
                cnt = 0U;
                idx++;
                if( idx == 1U ) {
                    LED_On(LED0);
                } else if( idx == 2U ) {
                    LED_On(LED1);
                    LED_Off(LED0);
                } else if( idx == 3U ) {
                    LED_On(LED2);
                    LED_Off(LED1);
                } else if( idx == 4U ) {
                    LED_On(LED3);
                    LED_Off(LED2);
                } else if( idx == 5U ) {
                    idx = 0U;
                    LED_Off(LED3);
                } else {
                    /* Do nothing */
                }
            } else {
                /* Do nothing */
            }  
        } else {
            /* Do nothing */
        }                                 
    }
} 

/**
  * @brief  Simulate a several mS timer. 
  * @param  None
  * @retval None
  */
static void softTimer(void)
{
    if( softT.time_Cnt == 0U ){
        softT.flag_TimeUp = 1U;
        softT.time_Cnt = DELAYCONST;
    } else {
        softT.time_Cnt --;
    }

}



#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
