/** 
 *******************************************************************************
 * @file    tmrb.c
 * @brief   the application functions of DNF demo for the TOSHIBA
 *          'TMPM37A' Device Series 
 * @version V0.100
 * @date    2015/11/02
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmrb.h"
/* external variables --------------------------------------------------------*/
extern uint32_t RG1Value;
extern uint32_t RG0Value;
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Configure TMRB PPG mode
  * @param  None
  * @retval None
  */
void TMRB7_Config(void)
{
    TMRB_InitTypeDef m_tmrb;
    TMRB_FFOutputTypeDef PPGFFInital;

    m_tmrb.Mode = TMRB_INTERVAL_TIMER;     /* internal timer */
    m_tmrb.ClkDiv = TMRB_CLK_DIV_2;        /* 1/2PhiT0 */
    m_tmrb.UpCntCtrl = TMRB_AUTO_CLEAR;    /* up-counter auto clear */
    m_tmrb.TrailingTiming = RG1Value;   /* T = 0.7us or 0.9 us */ 
    m_tmrb.LeadingTiming = RG0Value;    /* duty 50% */
    PPGFFInital.FlipflopCtrl = TMRB_FLIPFLOP_SET;
    PPGFFInital.FlipflopReverseTrg = TMRB_FLIPFLOP_MATCH_TRAILINGTIMING | TMRB_FLIPFLOP_MATCH_LEADINGTIMING;

    /* Enables TMRB7 operation */
    TMRB_Enable(TSB_TB7);
    /* Stop count operation */
    TMRB_SetRunState(TSB_TB7, TMRB_STOP);
    /* Disables TB7 double buffering */
    TMRB_SetDoubleBuf(TSB_TB7, DISABLE, TMRB_WRITE_REG_SEPARATE);
    /* Configure the basic PPG configuration */
    TMRB_Init(TSB_TB7, &m_tmrb);
    /* Enables the TB7 double buffering */
    TMRB_SetDoubleBuf(TSB_TB7, ENABLE, TMRB_WRITE_REG_SEPARATE);
    /* Set flip-flop control function */
    TMRB_SetFlipFlop(TSB_TB7, &PPGFFInital);
    
    /* Set PB6 as TB7OUT for PPG output */
    GPIO_SetOutput(GPIO_PB, GPIO_BIT_6);
    GPIO_EnableFuncReg(GPIO_PB, GPIO_FUNC_REG_3, GPIO_BIT_6);
}

/*********************************** END OF FILE ******************************/
