/**
 ******************************************************************************
 * @file     led.c
 * @brief    LED driver for the TOSHIBA 'TMPM37A' Device Series
 * @version  V2.0.2.1
 * @date     2015/11/02
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 ******************************************************************************
 */

/** include files **/

#include "led.h"

/*************************************************************************
 * Function Name: LED_Init
 * Parameters:None
 *
 * Return:None  
 *
 * Description: Init LED ports
 *
 *************************************************************************/
void LED_Init(void)
{
    /*Set PJ bit5~6,PM bit0~1 output and turn off all leds */
    GPIO_SetOutput(GPIO_PJ, GPIO_BIT_5);
    GPIO_SetOutput(GPIO_PJ, GPIO_BIT_6);
    GPIO_SetOutput(GPIO_PM, GPIO_BIT_0);
    GPIO_SetOutput(GPIO_PM, GPIO_BIT_1);

    GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_5, GPIO_BIT_VALUE_0);
    GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_6, GPIO_BIT_VALUE_0);
    GPIO_WriteDataBit(GPIO_PM, GPIO_BIT_0, GPIO_BIT_VALUE_0);
    GPIO_WriteDataBit(GPIO_PM, GPIO_BIT_1, GPIO_BIT_VALUE_0);
}

/*************************************************************************
 * Function Name: LED_On
 * Parameters:LED number, choose from LED0, LED1, LED2, LED3 or LED_ALL.
 *
 * Return:None  
 *
 * Description: The choosen Led is ON.
 *
 *************************************************************************/

void LED_On(uint8_t led)
{
    uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PJ);
    tmp |= ((led & 0x03) << 5U);
    GPIO_WriteData(GPIO_PJ, tmp);
    
    tmp = GPIO_ReadData(GPIO_PM);
    tmp |= ((led & 0x0C) >> 2U);
    GPIO_WriteData(GPIO_PM, tmp);
}

/*************************************************************************
 * Function Name: LED_Off
 * Parameters:LED number, choose from LED0, LED1, LED2, LED3 or LED_ALL.
 *
 * Return:None  
 *
 * Description: The choosen Led is Off.
 *
 *************************************************************************/
void LED_Off(uint8_t led)
{
    uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PJ);
    tmp &= (uint8_t) (~((led & 0x03) << 5U));
    GPIO_WriteData(GPIO_PJ, tmp);
    
    tmp = GPIO_ReadData(GPIO_PM);
    tmp &= (uint8_t) (~((led & 0x0C) >> 2U));
    GPIO_WriteData(GPIO_PM, tmp);
}
